"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  AuthenticationProvider: () => AuthenticationProvider_default,
  useAccount: () => useUserAccount_default,
  useAuthenticated: () => useAuthenticated_default,
  useAuthentication: () => useMsalAuthentication_default
});
module.exports = __toCommonJS(src_exports);

// src/AuthenticationProvider.tsx
var import_react5 = __toESM(require("react"));
var import_msal_browser3 = require("@azure/msal-browser");
var import_msal_react2 = require("@azure/msal-react");

// src/hooks/useConfiguration.ts
var import_react = require("react");
var import_msal_browser = require("@azure/msal-browser");

// src/configs/index.ts
var environmentConfig = () => ({
  clientId: getEnvironmentValue("MSAL_CLIENT_ID"),
  authority: getEnvironmentValue("MSAL_AUTHORITY"),
  loginRedirectUri: getEnvironmentValue("MSAL_REDIRECT_URL"),
  logoutRedirectUri: getEnvironmentValue("MSAL_LOGOUT_REDIRECT_URL"),
  scopes: getEnvironmentValue("MSAL_SCOPES"),
  cacheLoc: getEnvironmentValue("MSAL_CACHE_LOCATION"),
  tokenInterval: getEnvironmentValue("MSAL_TOKEN_INTERVAL"),
  tokenThreshold: getEnvironmentValue("MSAL_TOKEN_REFRESH_THRESHOLD")
});
var getEnvironmentValue = (key) => {
  if (key === void 0 || key === null) {
    throw new Error(`${key} not exists in the .env file`);
  }
  return process.env[`VITE_${key}`];
};
var Constants = {
  SPLIT_COMMA: ",",
  TOKEN_INTERVAL: 36e5,
  TOKEN_THRESHOLD: 300,
  SCOPES: ["User.Read"],
  MIDDLEWARE_URL: "_MIDDLEWARE_URL",
  MIDDLEWARE_KEY: "_MIDDLEWARE_KEY"
};
var ConstantsMessage = {
  MSG_ENV: "Missing environment configuration",
  MSG_CLIENT_ID: "Missing clientId",
  MSG_AUTH_URL: "Missing authority url",
  MSG_REDIRECT_URL: "Missing redirect url"
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [config, setConfig] = (0, import_react.useState)();
  const [options, setOptions] = (0, import_react.useState)();
  (0, import_react.useEffect)(() => {
    if (authConfig != null && authConfig.option) {
      setOptions(authConfig.option);
    }
    const clientInstance = authConfig && authConfig.instance ? authConfig.instance : defaultInstance();
    const msalInstance = new import_msal_browser.PublicClientApplication(clientInstance);
    if (msalInstance) {
      setConfig(msalInstance);
    }
  }, [authConfig]);
  const defaultInstance = () => {
    const env = environmentConfig();
    if (!env)
      throw new Error(ConstantsMessage.MSG_ENV);
    let interval = Constants.TOKEN_INTERVAL;
    let threshold = Constants.TOKEN_THRESHOLD;
    let cacheLoc = import_msal_browser.BrowserCacheLocation.LocalStorage;
    if (!env.clientId) {
      throw new Error(ConstantsMessage.MSG_CLIENT_ID);
    }
    if (!env.authority) {
      throw new Error(ConstantsMessage.MSG_AUTH_URL);
    }
    if (!env.loginRedirectUri) {
      throw new Error(ConstantsMessage.MSG_REDIRECT_URL);
    }
    if (env.tokenInterval) {
      interval = parseInt(env.tokenInterval);
    }
    if (env.tokenThreshold) {
      threshold = parseInt(env.tokenInterval);
    }
    if (env.cacheLoc) {
      cacheLoc = import_msal_browser.BrowserCacheLocation[env.cacheLoc];
    }
    setOptions({
      scopes: env.scopes?.split(Constants.SPLIT_COMMA),
      tokenInterval: interval,
      tokenThreshold: threshold
    });
    const defaultConfig = {
      auth: {
        clientId: env.clientId,
        authority: env.authority,
        redirectUri: env.loginRedirectUri,
        postLogoutRedirectUri: env.logoutRedirectUri,
        navigateToLoginRequestUrl: false
      },
      cache: {
        cacheLocation: cacheLoc,
        storeAuthStateInCookie: true
      },
      system: {
        tokenRenewalOffsetSeconds: Constants.TOKEN_THRESHOLD
      }
    };
    return defaultConfig;
  };
  return { config, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
var import_react4 = __toESM(require("react"));

// src/hooks/useUserAccount.ts
var import_react3 = require("react");
var import_msal_react = require("@azure/msal-react");
var import_msal_browser2 = require("@azure/msal-browser");
var import_jwt_decode = require("jwt-decode");
var import_unw_react_framework_user = require("unw.react.framework.user.identity");

// src/context/AuthenticationContext.ts
var import_react2 = require("react");
var AuthenticationContext = (0, import_react2.createContext)(null);

// src/hooks/useUserAccount.ts
var useUserAccount = () => {
  const { instance, accounts } = (0, import_msal_react.useMsal)();
  const authentication = (0, import_react3.useContext)(AuthenticationContext);
  const { setUserToken, getTokenInfo } = (0, import_unw_react_framework_user.useUserTokenService)();
  const { getAPIServiceTokenInfo, setAPIServiceToken } = (0, import_unw_react_framework_user.useAPITokenService)();
  const { setUserClaims } = (0, import_unw_react_framework_user.useUserClaimService)();
  const { setUserInfo } = (0, import_unw_react_framework_user.useUserService)();
  const getUserToken = async () => {
    const token = getTokenInfo();
    if (token && !isTokenExpired(0, token)) {
      return token;
    }
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
    }
    return accountInfo?.accessToken;
  };
  const getServiceApiAccessToken = async (key) => {
    const apiServiceToken = getAPIServiceTokenInfo(key);
    if (apiServiceToken && apiServiceToken != null) {
      if (!isTokenExpired(0, apiServiceToken.refreshToken)) {
        return apiServiceToken.refreshToken;
      } else if (!isTokenExpired(0, apiServiceToken.accessToken)) {
        return apiServiceToken.accessToken;
      }
    }
    const tokenInfo = await getApiTokenInfo(key);
    if (tokenInfo) {
      const sharePointToken = [
        {
          tokenId: key,
          refreshToken: tokenInfo.access_token,
          accessToken: tokenInfo.access_token,
          tokenExpirationDate: tokenInfo.expires_on.toLocaleString()
        }
      ];
      setAPIServiceToken(sharePointToken);
      return tokenInfo.access_token;
    }
    return null;
  };
  const getApiTokenInfo = async (key) => {
    const envKey = key.toUpperCase();
    const apiAccessUrl = getEnvironmentValue(envKey + Constants.MIDDLEWARE_URL);
    const middlewareKey = getEnvironmentValue(envKey + Constants.MIDDLEWARE_KEY);
    const response = await fetch(apiAccessUrl, {
      method: "GET",
      headers: {
        "X-Middleware-Key": middlewareKey
      }
    });
    return response.json();
  };
  const setClaims = async (userClaims) => {
    if (userClaims && userClaims.length > 0) {
      setUserClaims(userClaims);
    }
  };
  const getAcquireTokenSilent = async (scopes) => {
    const authRequest = { account: accounts[0], scopes: Constants.SCOPES };
    if (scopes != null && scopes.length > 0) {
      authRequest.scopes = scopes;
    }
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof import_msal_browser2.InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      setUserTokenToStore(accountInfo);
      setAccessTokenToStore(accountInfo);
    }
  };
  const setUserTokenToStore = (accountInfo) => {
    if (accountInfo) {
      const userToken = {
        tokenId: accountInfo.account?.localAccountId,
        idToken: accountInfo.account?.idToken,
        accessToken: accountInfo.accessToken,
        refreshToken: accountInfo.accessToken,
        tokenExpirationDate: accountInfo.expiresOn.toLocaleString()
      };
      setUserToken(userToken);
    }
  };
  const setAccessTokenToStore = (accountInfo) => {
    const accessToken = accountInfo.accessToken;
    if (accessToken) {
      const decodeToken = (0, import_jwt_decode.jwtDecode)(accessToken);
      if (decodeToken) {
        const user = {
          name: decodeToken.name,
          firstname: decodeToken.given_name,
          lastName: decodeToken.family_name,
          email: accountInfo.username,
          upn: decodeToken.upn,
          guid: decodeToken.oid
        };
        setUserInfo(user);
      }
    }
  };
  const setAcquireTokenToStore = async () => {
    const scopes = authentication?.option?.scopes;
    const accountInfo = await getAcquireTokenSilent(scopes);
    if (accountInfo) {
      setAccountInfoToStore(accountInfo);
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
    await setAcquireTokenToStore();
    setRefreshTokenInterval();
  };
  const setRefreshTokenInterval = () => {
    const option = authentication?.option;
    const threshold = option?.tokenThreshold ?? Constants.TOKEN_THRESHOLD;
    const interval = option?.tokenInterval ?? Constants.TOKEN_INTERVAL;
    setInterval(() => {
      const token = getTokenInfo();
      if (token === void 0 || isTokenExpired(threshold, token)) {
        setAcquireTokenToStore();
      }
    }, interval);
  };
  const isTokenExpired = (tokenThreshold, token) => {
    let isExpired = false;
    if (token && token != null) {
      const decodeToken = (0, import_jwt_decode.jwtDecode)(token);
      if (decodeToken.exp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = decodeToken.exp - currentTime;
        isExpired = timeUntilExpiry <= (tokenThreshold ?? 0);
      }
    }
    return isExpired;
  };
  return { getUserToken, getServiceApiAccessToken, setUserActiveAccount, setClaims };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children }) => {
  const { setUserActiveAccount } = useUserAccount_default();
  (0, import_react4.useEffect)(() => {
    setUserActiveAccount();
  }, []);
  return /* @__PURE__ */ import_react4.default.createElement(import_react4.default.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ import_react5.default.createElement(AuthenticationContext.Provider, { value: { option } }, /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ import_react5.default.createElement(import_react5.default.Fragment, null, /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.AuthenticatedTemplate, null, /* @__PURE__ */ import_react5.default.createElement(AuthenticationSuccess_default, null, children))) : /* @__PURE__ */ import_react5.default.createElement(import_react5.default.Fragment, null, /* @__PURE__ */ import_react5.default.createElement(import_msal_react2.MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: import_msal_browser3.InteractionType.Redirect }, /* @__PURE__ */ import_react5.default.createElement(AuthenticationSuccess_default, null, children))))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
var import_msal_react3 = require("@azure/msal-react");
var useMsalAuthentication = () => {
  const { instance } = (0, import_msal_react3.useMsal)();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
var import_msal_react4 = require("@azure/msal-react");
var useAuthenticated = () => {
  const isAuthenticated = (0, import_msal_react4.useIsAuthenticated)();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AuthenticationProvider,
  useAccount,
  useAuthenticated,
  useAuthentication
});
